@@ -16,8 +16,8 @@ class MemberEvents(EventMixinTemplate):
     async def _on_raw_guild_member_add(self, event: "RawGatewayEvent") -> None:
         g_id = event.data.pop("guild_id")
         member = self.cache.place_member_data(g_id, event.data)
-        guild = self.cache.get_guild(g_id)
-        guild.member_count += 1
+        if guild := self.cache.get_guild(g_id):
+            guild.member_count += 1
         self.dispatch(events.MemberAdd(g_id, member))
 
     @Processor.define()
@@ -27,8 +27,8 @@ class MemberEvents(EventMixinTemplate):
         member = self.cache.get_member(g_id, user.id)
 
         self.cache.delete_member(g_id, user.id)
-        guild = self.cache.get_guild(g_id)
-        guild.member_count -= 1
+        if guild := self.cache.get_guild(g_id):
+            guild.member_count -= 1
 
         self.dispatch(events.MemberRemove(g_id, member or user))
 
