@@ -5,14 +5,13 @@ import time
 import zlib
 from abc import abstractmethod
 from types import TracebackType
-from aiohttp import WSMsgType
 from typing import TypeVar, TYPE_CHECKING
 
-from naff.client.const import logger
-from naff.client.errors import WebSocketClosed
-from naff.models.naff.cooldowns import CooldownSystem
+from aiohttp import WSMsgType
 
+from naff.client.errors import WebSocketClosed
 from naff.client.utils.input_utils import OverriddenJson
+from naff.models.naff.cooldowns import CooldownSystem
 
 if TYPE_CHECKING:
     from naff.api.gateway.state import ConnectionState
@@ -41,6 +40,7 @@ class WebsocketRateLimit:
 class WebsocketClient:
     def __init__(self, state: "ConnectionState") -> None:
         self.state = state
+        self.logger = state.client.logger
         self.ws = None
         self.ws_url = None
 
@@ -134,11 +134,11 @@ class WebsocketClient:
             bypass: Should the rate limit be ignored for this send (used for heartbeats)
 
         """
-        logger.debug(f"Sending data to websocket: {data}")
+        self.logger.debug(f"Sending data to websocket: {data}")
 
         async with self._race_lock:
             if self.ws is None:
-                return logger.warning("Attempted to send data while websocket is not connected!")
+                return self.logger.warning("Attempted to send data while websocket is not connected!")
             if not bypass:
                 await self.rl_manager.rate_limit()
 
@@ -177,7 +177,7 @@ class WebsocketClient:
             resp = await self.ws.receive()
 
             if resp.type == WSMsgType.CLOSE:
-                logger.debug(f"Disconnecting from gateway! Reason: {resp.data}::{resp.extra}")
+                self.logger.debug(f"Disconnecting from gateway! Reason: {resp.data}::{resp.extra}")
                 if resp.data >= 4000:
                     # This should propagate to __aexit__() which will forcefully shut down everything
                     # and cleanup correctly.
@@ -232,7 +232,7 @@ class WebsocketClient:
             try:
                 msg = OverriddenJson.loads(msg)
             except Exception as e:
-                logger.error(e)
+                self.logger.error(e)
                 continue
 
             return msg
@@ -270,7 +270,7 @@ class WebsocketClient:
             await self._start_bee_gees()
         except Exception:
             self.close()
-            logger.error("The heartbeater raised an exception!", exc_info=True)
+            self.logger.error("The heartbeater raised an exception!", exc_info=True)
 
     async def _start_bee_gees(self) -> None:
         if self.heartbeat_interval is None:
@@ -283,10 +283,10 @@ class WebsocketClient:
         else:
             return
 
-        logger.debug(f"Sending heartbeat every {self.heartbeat_interval} seconds")
+        self.logger.debug(f"Sending heartbeat every {self.heartbeat_interval} seconds")
         while not self._kill_bee_gees.is_set():
             if not self._acknowledged.is_set():
-                logger.warning(
+                self.logger.warning(
                     f"Heartbeat has not been acknowledged for {self.heartbeat_interval} seconds,"
                     " likely zombied connection. Reconnect!"
                 )
