@@ -1,8 +1,9 @@
-import logging
+import asyncio
 import platform
+import tracemalloc
 
 from naff import Client, Extension, listen, slash_command, InteractionContext, Timestamp, TimestampStyles, Intents
-from naff.client.const import logger, __version__, __py_version__
+from naff.client.const import get_logger, __version__, __py_version__
 from naff.models.naff import checks
 from .debug_application_cmd import DebugAppCMD
 from .debug_exec import DebugExec
@@ -14,16 +15,25 @@ __all__ = ("DebugExtension",)
 
 class DebugExtension(DebugExec, DebugAppCMD, DebugExts, Extension):
     def __init__(self, bot: Client) -> None:
+        bot.logger.info("Debug Extension is mounting!")
+
         super().__init__(bot)
         self.add_ext_check(checks.is_owner())
 
-        logger.info("Debug Extension is growing!")
+        bot.logger.info("Debug Extension is growing!")
+        tracemalloc.start()
+        bot.logger.warning("Tracemalloc started")
+
+    async def async_start(self) -> None:
+        loop = asyncio.get_running_loop()
+        loop.set_debug(True)
+        self.bot.logger.warning("Asyncio debug mode is enabled")
 
     @listen()
     async def on_startup(self) -> None:
-        logger.info(f"Started {self.bot.user.tag} [{self.bot.user.id}] in Debug Mode")
+        self.bot.logger.info(f"Started {self.bot.user.tag} [{self.bot.user.id}] in Debug Mode")
 
-        logger.info(f"Caching System State: \n{get_cache_state(self.bot)}")
+        self.bot.logger.info(f"Caching System State: \n{get_cache_state(self.bot)}")
 
     @slash_command(
         "debug",
