@@ -2,8 +2,9 @@ from asyncio import QueueEmpty
 from collections import namedtuple
 from typing import TYPE_CHECKING, List, Optional
 
+import attrs
+
 from naff.client.const import MISSING
-from naff.client.utils.attr_utils import define, field
 from naff.models.discord.emoji import PartialEmoji
 from naff.models.discord.snowflake import to_snowflake
 from naff.models.misc.iterator import AsyncIterator
@@ -64,17 +65,19 @@ class ReactionUsers(AsyncIterator):
             raise QueueEmpty
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class Reaction(ClientObject):
-    count: int = field()
+    count: int = attrs.field(
+        repr=False,
+    )
     """times this emoji has been used to react"""
-    me: bool = field(default=False)
+    me: bool = attrs.field(repr=False, default=False)
     """whether the current user reacted using this emoji"""
-    emoji: "PartialEmoji" = field(converter=PartialEmoji.from_dict)
+    emoji: "PartialEmoji" = attrs.field(repr=False, converter=PartialEmoji.from_dict)
     """emoji information"""
 
-    _channel_id: "Snowflake_Type" = field(converter=to_snowflake)
-    _message_id: "Snowflake_Type" = field(converter=to_snowflake)
+    _channel_id: "Snowflake_Type" = attrs.field(repr=False, converter=to_snowflake)
+    _message_id: "Snowflake_Type" = attrs.field(repr=False, converter=to_snowflake)
 
     def users(self, limit: int = 0, after: "Snowflake_Type" = None) -> ReactionUsers:
         """Users who reacted using this emoji."""
