@@ -1,19 +1,22 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Protocol, Union, runtime_checkable
+from logging import Logger
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Optional, Protocol, Union, runtime_checkable, Sequence
 
+import attrs
 from aiohttp import FormData
 
+import naff.models as models
 import naff.models.discord.message as message
-from naff.models.discord.timestamp import Timestamp
-from naff.client.const import MISSING, logger, Absent
+from naff.client.const import Absent, MISSING, get_logger
 from naff.client.errors import AlreadyDeferred
 from naff.client.mixins.send import SendMixin
-from naff.client.utils.attr_utils import define, field, docs
 from naff.client.utils.attr_converters import optional
+from naff.client.utils.attr_utils import docs
 from naff.models.discord.enums import MessageFlags, CommandTypes, Permissions
 from naff.models.discord.file import UPLOADABLE_TYPE
 from naff.models.discord.message import Attachment
 from naff.models.discord.snowflake import to_snowflake, to_optional_snowflake
+from naff.models.discord.timestamp import Timestamp
 from naff.models.naff.application_commands import CallbackTypes, OptionTypes
 
 if TYPE_CHECKING:
@@ -49,27 +52,27 @@ __all__ = (
 )
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class Resolved:
     """Represents resolved data in an interaction."""
 
-    channels: Dict["Snowflake_Type", "TYPE_MESSAGEABLE_CHANNEL"] = field(
-        factory=dict, metadata=docs("A dictionary of channels mentioned in the interaction")
+    channels: Dict["Snowflake_Type", "TYPE_MESSAGEABLE_CHANNEL"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of channels mentioned in the interaction")
     )
-    members: Dict["Snowflake_Type", "Member"] = field(
-        factory=dict, metadata=docs("A dictionary of members mentioned in the interaction")
+    members: Dict["Snowflake_Type", "Member"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of members mentioned in the interaction")
     )
-    users: Dict["Snowflake_Type", "User"] = field(
-        factory=dict, metadata=docs("A dictionary of users mentioned in the interaction")
+    users: Dict["Snowflake_Type", "User"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of users mentioned in the interaction")
     )
-    roles: Dict["Snowflake_Type", "Role"] = field(
-        factory=dict, metadata=docs("A dictionary of roles mentioned in the interaction")
+    roles: Dict["Snowflake_Type", "Role"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of roles mentioned in the interaction")
     )
-    messages: Dict["Snowflake_Type", "Message"] = field(
-        factory=dict, metadata=docs("A dictionary of messages mentioned in the interaction")
+    messages: Dict["Snowflake_Type", "Message"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of messages mentioned in the interaction")
     )
-    attachments: Dict["Snowflake_Type", "Attachment"] = field(
-        factory=dict, metadata=docs("A dictionary of attachments tied to the interaction")
+    attachments: Dict["Snowflake_Type", "Attachment"] = attrs.field(
+        repr=False, factory=dict, metadata=docs("A dictionary of attachments tied to the interaction")
     )
 
     @classmethod
@@ -105,23 +108,34 @@ class Resolved:
         return new_cls
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class Context:
     """Represents the context of a command."""
 
-    _client: "Client" = field(default=None)
-    invoke_target: str = field(default=None, metadata=docs("The name of the command to be invoked"))
-    command: Optional["BaseCommand"] = field(default=None, metadata=docs("The command to be invoked"))
+    _client: "Client" = attrs.field(repr=False, default=None)
+    invoke_target: str = attrs.field(repr=False, default=None, metadata=docs("The name of the command to be invoked"))
+    command: Optional["BaseCommand"] = attrs.field(repr=False, default=None, metadata=docs("The command to be invoked"))
 
-    args: List = field(factory=list, metadata=docs("The list of arguments to be passed to the command"))
-    kwargs: Dict = field(factory=dict, metadata=docs("The list of keyword arguments to be passed"))
-
-    author: Union["Member", "User"] = field(default=None, metadata=docs("The author of the message"))
-    channel: "TYPE_MESSAGEABLE_CHANNEL" = field(default=None, metadata=docs("The channel this was sent within"))
-    guild_id: "Snowflake_Type" = field(
-        default=None, converter=to_optional_snowflake, metadata=docs("The guild this was sent within, if not a DM")
+    args: List = attrs.field(
+        repr=False, factory=list, metadata=docs("The list of arguments to be passed to the command")
     )
-    message: "Message" = field(default=None, metadata=docs("The message associated with this context"))
+    kwargs: Dict = attrs.field(repr=False, factory=dict, metadata=docs("The list of keyword arguments to be passed"))
+
+    author: Union["Member", "User"] = attrs.field(repr=False, default=None, metadata=docs("The author of the message"))
+    channel: "TYPE_MESSAGEABLE_CHANNEL" = attrs.field(
+        repr=False, default=None, metadata=docs("The channel this was sent within")
+    )
+    guild_id: "Snowflake_Type" = attrs.field(
+        repr=False,
+        default=None,
+        converter=to_optional_snowflake,
+        metadata=docs("The guild this was sent within, if not a DM"),
+    )
+    message: "Message" = attrs.field(
+        repr=False, default=None, metadata=docs("The message associated with this context")
+    )
+
+    logger: Logger = attrs.field(repr=False, init=False, factory=get_logger)
 
     @property
     def guild(self) -> Optional["Guild"]:
@@ -137,36 +151,44 @@ class Context:
         return self._client.cache.get_bot_voice_state(self.guild_id)
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class _BaseInteractionContext(Context):
     """An internal object used to define the attributes of interaction context and its children."""
 
-    _token: str = field(default=None, metadata=docs("The token for the interaction"))
-    _context_type: int = field()  # we don't want to convert this in case of a new context type, which is expected
-    interaction_id: str = field(default=None, metadata=docs("The id of the interaction"))
-    target_id: "Snowflake_Type" = field(
+    _token: str = attrs.field(repr=False, default=None, metadata=docs("The token for the interaction"))
+    _context_type: int = attrs.field(
+        repr=False,
+    )  # we don't want to convert this in case of a new context type, which is expected
+    interaction_id: "Snowflake_Type" = attrs.field(
+        repr=False, default=None, metadata=docs("The id of the interaction"), converter=to_snowflake
+    )
+    target_id: "Snowflake_Type" = attrs.field(
         default=None,
         metadata=docs("The ID of the target, used for context menus to show what was clicked on"),
         converter=optional(to_snowflake),
     )
-    app_permissions: Permissions = field(
-        default=0, converter=Permissions, metadata=docs("The permissions this interaction has")
+    app_permissions: Permissions = attrs.field(
+        repr=False, default=0, converter=Permissions, metadata=docs("The permissions this interaction has")
     )
-    locale: str = field(
+    locale: str = attrs.field(
         default=None,
         metadata=docs(
             "The selected language of the invoking user \n(https://discord.com/developers/docs/reference#locales)"
         ),
     )
-    guild_locale: str = field(default=None, metadata=docs("The guild's preferred locale"))
+    guild_locale: str = attrs.field(repr=False, default=None, metadata=docs("The guild's preferred locale"))
 
-    deferred: bool = field(default=False, metadata=docs("Is this interaction deferred?"))
-    responded: bool = field(default=False, metadata=docs("Have we responded to the interaction?"))
-    ephemeral: bool = field(default=False, metadata=docs("Are responses to this interaction *hidden*"))
+    deferred: bool = attrs.field(repr=False, default=False, metadata=docs("Is this interaction deferred?"))
+    responded: bool = attrs.field(repr=False, default=False, metadata=docs("Have we responded to the interaction?"))
+    ephemeral: bool = attrs.field(
+        repr=False, default=False, metadata=docs("Are responses to this interaction *hidden*")
+    )
 
-    resolved: Resolved = field(default=Resolved(), metadata=docs("Discord objects mentioned within this interaction"))
+    resolved: Resolved = attrs.field(
+        repr=False, default=Resolved(), metadata=docs("Discord objects mentioned within this interaction")
+    )
 
-    data: Dict = field(factory=dict, metadata=docs("The raw data of this interaction"))
+    data: Dict = attrs.field(repr=False, factory=dict, metadata=docs("The raw data of this interaction"))
 
     @classmethod
     def from_dict(cls, data: Dict, client: "Client") -> "Context":
@@ -286,7 +308,7 @@ class _BaseInteractionContext(Context):
         return modal
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class InteractionContext(_BaseInteractionContext, SendMixin):
     """
     Represents the context of an interaction.
@@ -345,6 +367,7 @@ class InteractionContext(_BaseInteractionContext, SendMixin):
     async def send(
         self,
         content: Optional[str] = None,
+        *,
         embeds: Optional[Union[Iterable[Union["Embed", dict]], Union["Embed", dict]]] = None,
         embed: Optional[Union["Embed", dict]] = None,
         components: Optional[
@@ -410,6 +433,62 @@ class InteractionContext(_BaseInteractionContext, SendMixin):
             flags=flags,
         )
 
+    async def delete(self, message: "Snowflake_Type") -> None:
+        """
+        Delete a message sent in response to this interaction.
+
+        Args:
+            message: The message to delete
+
+        """
+        await self._client.http.delete_interaction_message(self._client.app.id, self._token, to_snowflake(message))
+
+    async def edit(
+        self,
+        message: "Snowflake_Type",
+        *,
+        content: Optional[str] = None,
+        embeds: Optional[Union[Sequence[Union["models.Embed", dict]], Union["models.Embed", dict]]] = None,
+        embed: Optional[Union["models.Embed", dict]] = None,
+        components: Optional[
+            Union[
+                Sequence[Sequence[Union["models.BaseComponent", dict]]],
+                Sequence[Union["models.BaseComponent", dict]],
+                "models.BaseComponent",
+                dict,
+            ]
+        ] = None,
+        allowed_mentions: Optional[Union["models.AllowedMentions", dict]] = None,
+        attachments: Optional[Optional[Sequence[Union[Attachment, dict]]]] = None,
+        files: Optional[Union[UPLOADABLE_TYPE, Sequence[UPLOADABLE_TYPE]]] = None,
+        file: Optional[UPLOADABLE_TYPE] = None,
+        tts: bool = False,
+    ) -> "models.Message":
+        message_payload = models.process_message_payload(
+            content=content,
+            embeds=embeds or embed,
+            components=components,
+            allowed_mentions=allowed_mentions,
+            attachments=attachments,
+            tts=tts,
+        )
+
+        if file:
+            if files:
+                files = [file, *files]
+            else:
+                files = [file]
+
+        message_data = await self._client.http.edit_interaction_message(
+            payload=message_payload,
+            application_id=self._client.app.id,
+            token=self._token,
+            message_id=to_snowflake(message),
+            files=files,
+        )
+        if message_data:
+            return self._client.cache.place_message_data(message_data)
+
     @property
     def target(self) -> "Absent[Member | User | Message]":
         """For context menus, this will be the object of which was clicked on."""
@@ -422,21 +501,21 @@ class InteractionContext(_BaseInteractionContext, SendMixin):
                 # This can only be in the member or user cache
                 caches = (
                     (self._client.cache.get_member, (self.guild_id, self.target_id)),
-                    (self._client.cache.get_user, self.target_id),
+                    (self._client.cache.get_user, (self.target_id,)),
                 )
             case CommandTypes.MESSAGE:
                 # This can only be in the message cache
                 caches = ((self._client.cache.get_message, (self.channel.id, self.target_id)),)
             case _:
                 # Most likely a new context type, check all rational caches for the target_id
-                logger.warning(f"New Context Type Detected. Please Report: {self._context_type}")
+                self.logger.warning(f"New Context Type Detected. Please Report: {self._context_type}")
                 caches = (
                     (self._client.cache.get_message, (self.channel.id, self.target_id)),
                     (self._client.cache.get_member, (self.guild_id, self.target_id)),
-                    (self._client.cache.get_user, self.target_id),
-                    (self._client.cache.get_channel, self.target_id),
-                    (self._client.cache.get_role, self.target_id),
-                    (self._client.cache.get_emoji, self.target_id),  # unlikely, so check last
+                    (self._client.cache.get_user, (self.target_id,)),
+                    (self._client.cache.get_channel, (self.target_id,)),
+                    (self._client.cache.get_role, (self.target_id,)),
+                    (self._client.cache.get_emoji, (self.target_id,)),  # unlikely, so check last
                 )
 
         for cache, keys in caches:
@@ -446,14 +525,20 @@ class InteractionContext(_BaseInteractionContext, SendMixin):
         return thing
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class ComponentContext(InteractionContext):
-    custom_id: str = field(default="", metadata=docs("The ID given to the component that has been pressed"))
-    component_type: int = field(default=0, metadata=docs("The type of component that has been pressed"))
+    custom_id: str = attrs.field(
+        repr=False, default="", metadata=docs("The ID given to the component that has been pressed")
+    )
+    component_type: int = attrs.field(
+        repr=False, default=0, metadata=docs("The type of component that has been pressed")
+    )
 
-    values: List = field(factory=list, metadata=docs("The values set"))
+    values: List = attrs.field(repr=False, factory=list, metadata=docs("The values set"))
 
-    defer_edit_origin: bool = field(default=False, metadata=docs("Are we editing the message the component is on"))
+    defer_edit_origin: bool = attrs.field(
+        repr=False, default=False, metadata=docs("Are we editing the message the component is on")
+    )
 
     @classmethod
     def from_dict(cls, data: Dict, client: "Client") -> "ComponentContext":
@@ -461,6 +546,7 @@ class ComponentContext(InteractionContext):
         new_cls = super().from_dict(data, client)
         new_cls.token = data["token"]
         new_cls.interaction_id = data["id"]
+        new_cls.invoke_target = data["data"]["custom_id"]
         new_cls.custom_id = data["data"]["custom_id"]
         new_cls.component_type = data["data"]["component_type"]
         new_cls.message = client.cache.place_message_data(data["message"])
@@ -498,6 +584,7 @@ class ComponentContext(InteractionContext):
 
     async def edit_origin(
         self,
+        *,
         content: str = None,
         embeds: Optional[Union[Iterable[Union["Embed", dict]], Union["Embed", dict]]] = None,
         embed: Optional[Union["Embed", dict]] = None,
@@ -546,7 +633,7 @@ class ComponentContext(InteractionContext):
         message_data = None
         if self.deferred:
             if not self.defer_edit_origin:
-                logger.warning(
+                self.logger.warning(
                     "If you want to edit the original message, and need to defer, you must set the `edit_origin` kwarg to True!"
                 )
 
@@ -567,9 +654,11 @@ class ComponentContext(InteractionContext):
             return self.message
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class AutocompleteContext(_BaseInteractionContext):
-    focussed_option: str = field(default=MISSING, metadata=docs("The option the user is currently filling in"))
+    focussed_option: str = attrs.field(
+        repr=False, default=MISSING, metadata=docs("The option the user is currently filling in")
+    )
 
     @classmethod
     def from_dict(cls, data: Dict, client: "Client") -> "ComponentContext":
@@ -614,9 +703,9 @@ class AutocompleteContext(_BaseInteractionContext):
         await self._client.http.post_initial_response(payload, self.interaction_id, self._token)
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class ModalContext(InteractionContext):
-    custom_id: str = field(default="")
+    custom_id: str = attrs.field(repr=False, default="")
 
     @classmethod
     def from_dict(cls, data: Dict, client: "Client") -> "ModalContext":
@@ -639,9 +728,9 @@ class ModalContext(InteractionContext):
         return self.kwargs
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class PrefixedContext(Context, SendMixin):
-    prefix: str = field(default=MISSING, metadata=docs("The prefix used to invoke this command"))
+    prefix: str = attrs.field(repr=False, default=MISSING, metadata=docs("The prefix used to invoke this command"))
 
     @classmethod
     def from_message(cls, client: "Client", message: "Message") -> "PrefixedContext":
@@ -674,7 +763,7 @@ class PrefixedContext(Context, SendMixin):
         return await self._client.http.create_message(message_payload, self.channel.id, files=files)
 
 
-@define
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class HybridContext(Context):
     """
     Represents the context for hybrid commands, a slash command that can also be used as a prefixed command.
@@ -682,14 +771,14 @@ class HybridContext(Context):
     This attempts to create a compatibility layer to allow contexts for an interaction or a message to be used seamlessly.
     """
 
-    deferred: bool = field(default=False, metadata=docs("Is this context deferred?"))
-    responded: bool = field(default=False, metadata=docs("Have we responded to this?"))
-    app_permissions: Permissions = field(
-        default=0, converter=Permissions, metadata=docs("The permissions this context has")
+    deferred: bool = attrs.field(repr=False, default=False, metadata=docs("Is this context deferred?"))
+    responded: bool = attrs.field(repr=False, default=False, metadata=docs("Have we responded to this?"))
+    app_permissions: Permissions = attrs.field(
+        repr=False, default=0, converter=Permissions, metadata=docs("The permissions this context has")
     )
 
-    _interaction_context: Optional[InteractionContext] = field(default=None)
-    _prefixed_context: Optional[PrefixedContext] = field(default=None)
+    _interaction_context: Optional[InteractionContext] = attrs.field(repr=False, default=None)
+    _prefixed_context: Optional[PrefixedContext] = attrs.field(repr=False, default=None)
 
     @classmethod
     def from_interaction_context(cls, context: InteractionContext) -> "HybridContext":
@@ -815,6 +904,7 @@ class HybridContext(Context):
     async def send(
         self,
         content: Optional[str] = None,
+        *,
         embeds: Optional[Union[Iterable[Union["Embed", dict]], Union["Embed", dict]]] = None,
         embed: Optional[Union["Embed", dict]] = None,
         components: Optional[
@@ -897,7 +987,9 @@ class SendableContext(Protocol):
     async def send(
         self,
         content: Optional[str] = None,
+        *,
         embeds: Optional[Union[Iterable[Union["Embed", dict]], Union["Embed", dict]]] = None,
+        embed: Optional[Union["Embed", dict]] = None,
         components: Optional[
             Union[
                 Iterable[Iterable[Union["BaseComponent", dict]]],
@@ -909,9 +1001,12 @@ class SendableContext(Protocol):
         stickers: Optional[Union[Iterable[Union["Sticker", "Snowflake_Type"]], "Sticker", "Snowflake_Type"]] = None,
         allowed_mentions: Optional[Union["AllowedMentions", dict]] = None,
         reply_to: Optional[Union["MessageReference", "Message", dict, "Snowflake_Type"]] = None,
-        file: Optional[Union["File", "IOBase", "Path", str]] = None,
+        files: Optional[Union["UPLOADABLE_TYPE", Iterable["UPLOADABLE_TYPE"]]] = None,
+        file: Optional["UPLOADABLE_TYPE"] = None,
         tts: bool = False,
+        suppress_embeds: bool = False,
         flags: Optional[Union[int, "MessageFlags"]] = None,
+        delete_after: Optional[float] = None,
         **kwargs: Any,
     ) -> "Message":
         ...
